@@ -3,7 +3,7 @@
 
 #include "global.h"
 
-#if defined (Q_OS_UNIX) && !defined (Q_OS_SYMBIAN)
+#if TELEPATHY_CAPABLE
 #include <TelepathyQt4/Constants>
 #include <TelepathyQt4/Types>
 #if !NO_DBGINFO
@@ -11,6 +11,10 @@
 #endif
 #endif
 
+#ifdef Q_WS_MAEMO_5
+#include <QtMaemo5>
+#endif
+
 class OsDependent : public QObject
 {
     Q_OBJECT
@@ -20,6 +24,7 @@ public:
     bool isN900 ();
     void initDialServer (QObject *receiver, const char *method);
     void setDefaultWindowAttributes (QWidget *pWidget);
+    void setLongWork (QWidget *window, bool bSet = false);
 
 private:
     OsDependent(QObject *parent = 0);
